@@ -28,12 +28,7 @@ from safe_cli.api.etherscan_api import EtherscanApi
 from safe_cli.api.relay_service_api import RelayServiceApi
 from safe_cli.api.transaction_service_api import TransactionServiceApi
 from safe_cli.ethereum_hd_wallet import get_account_from_words
-from safe_cli.safe_addresses import (
-    LAST_DEFAULT_CALLBACK_HANDLER,
-    LAST_MULTISEND_CALL_ONLY_CONTRACT,
-    LAST_MULTISEND_CONTRACT,
-    LAST_SAFE_CONTRACT,
-)
+from safe_cli.safe_addresses import LAST_DEFAULT_CALLBACK_HANDLER, LAST_SAFE_CONTRACT
 from safe_cli.utils import get_erc_20_list, yes_or_no_question
 
 try:
@@ -196,7 +191,7 @@ class SafeOperator:
             self.ethereum_client
         )
         self.safe = Safe(address, self.ethereum_client)
-        self.safe_contract = self.safe.get_contract()
+        self.safe_contract = self.safe.contract
         self.safe_contract_1_1_0 = get_safe_V1_1_1_contract(
             self.ethereum_client.w3, address=self.address
         )
@@ -530,7 +525,7 @@ class SafeOperator:
                 "Not valid addresses to update Safe", *addresses
             )
 
-        multisend = MultiSend(LAST_MULTISEND_CONTRACT, self.ethereum_client)
+        multisend = MultiSend(ethereum_client=self.ethereum_client)
         tx_params = {"from": self.address, "gas": 0, "gasPrice": 0}
         multisend_txs = [
             MultiSendTx(MultiSendOperation.CALL, self.address, 0, data)
@@ -756,18 +751,24 @@ class SafeOperator:
         return False
 
     # Batch_transactions multisend
-    def batch_safe_txs(self, safe_nonce: int, safe_txs: [SafeTx]) -> SafeTx:
+    def batch_safe_txs(
+        self, safe_nonce: int, safe_txs: Sequence[SafeTx]
+    ) -> Optional[SafeTx]:
         """
         Submit signatures to the tx service. It's recommended to be on Safe v1.3.0 to prevent issues
         with `safeTxGas` and gas estimation.
 
         :return:
         """
-        if not self.ethereum_client.is_contract(LAST_MULTISEND_CALL_ONLY_CONTRACT):
+
+        try:
+            multisend = MultiSend(ethereum_client=self.ethereum_client)
+        except ValueError:
+            multisend = None
             print_formatted_text(
                 HTML(
-                    f"<ansired>Multisend call only contract {LAST_MULTISEND_CALL_ONLY_CONTRACT} "
-                    f"is not deployed on this network and it's required for batching txs</ansired>"
+                    "<ansired>Multisend contract is not deployed on this network and it's required for "
+                    "batching txs</ansired>"
                 )
             )
 
@@ -784,14 +785,17 @@ class SafeOperator:
                     )
                 )
 
-        if len(multisend_txs) > 1:
-            multisend = MultiSend(
-                LAST_MULTISEND_CALL_ONLY_CONTRACT, self.ethereum_client
-            )
+        if len(multisend_txs) == 1:
+            safe_tx.safe_tx_gas = 0
+            safe_tx.base_gas = 0
+            safe_tx.gas_price = 0
+            safe_tx.signatures = b""
+            safe_tx.safe_nonce = safe_nonce  # Resend single transaction
+        elif multisend:
             safe_tx = SafeTx(
                 self.ethereum_client,
                 self.address,
-                LAST_MULTISEND_CALL_ONLY_CONTRACT,
+                multisend.address,
                 0,
                 multisend.build_tx_data(multisend_txs),
                 SafeOperation.DELEGATE_CALL.value,
@@ -803,11 +807,9 @@ class SafeOperator:
                 safe_nonce=safe_nonce,
             )
         else:
-            safe_tx.safe_tx_gas = 0
-            safe_tx.base_gas = 0
-            safe_tx.gas_price = 0
-            safe_tx.signatures = b""
-            safe_tx.safe_nonce = safe_nonce  # Resend single transaction
+            # Multisend not defined
+            return None
+
         safe_tx = self.sign_transaction(safe_tx)
         if not safe_tx.signatures:
             print_formatted_text(
@@ -898,9 +900,10 @@ class SafeOperator:
                     safe_nonce=None,
                 )
                 safe_txs.append(safe_tx)
+
         # Getting ethereum balance
         balance_eth = self.ethereum_client.get_balance(self.address)
-        if balance_eth > 0:
+        if balance_eth:
             safe_tx = self.prepare_safe_transaction(
                 to,
                 balance_eth,
@@ -909,7 +912,8 @@ class SafeOperator:
                 safe_nonce=None,
             )
             safe_txs.append(safe_tx)
-        if len(safe_txs) > 0:
+
+        if safe_txs:
             multisend_tx = self.batch_safe_txs(self.get_nonce(), safe_txs)
             if multisend_tx is not None:
                 if self.execute_safe_transaction(multisend_tx):
